// Include the required libraries
#include <esp_now.h>
#include <WiFi.h>
#include <DriveCell.h>

// Define the control pins on the ESP32 dev board
#define IN1_pin1 32
#define IN1_pin2 33

// Define the structure of the recieved data
typedef struct struct_message {
    int b;
} struct_message;
struct_message myData;

// Variables needed for motor control. 
int speed_percentage = 0;
DriveCell Motor1(IN1_pin1, IN1_pin2);
int motorDirection;

// Function that handles and sends data to the Serial output.
void OnDataRecv(const uint8_t * mac, const uint8_t *incomingData, int len) {
  memcpy(&myData, incomingData, sizeof(myData));
  Serial.print("Bytes received: ");
  Serial.println(len);
}
 
void setup() {
  // Initialize Serial Monitor
  Serial.begin(115200);

  // Initialize the driveCell H-Bridge motor driver
  Motor1.Init();

  // Set device as a Wi-Fi Station
  WiFi.mode(WIFI_STA);

  // Initialize ESP-NOW
  if (esp_now_init() != ESP_OK) {
    Serial.println("Unable to start ESP-NOW");
    return;
  }
  esp_now_register_recv_cb(esp_now_recv_cb_t(OnDataRecv));
}
 
void loop() {
  // Convert the recieved motor command into a direction command and a speed percentage. 
  if(myData.b > 0){
    motorDirection = 1;
    speed_percentage = myData.b;
  }else{
    motorDirection = 0;
    speed_percentage = myData.b * -1;
  }
  // Send direction and speed percentage commands to the motor driver.
      Motor1.Drive(motorDirection, speed_percentage);
}
